#!/bin/sh
#  
#  novell-pure-ftpd-config.sh
#
#  Copyright (C) 2007 Novell, Inc.
#
#  This script does 3 things :-
#  1) By default, pure-ftpd package installs a PAM file (/etc/pam.d/pure-ftpd) 
#     with file-based (/etc/passwd) authentication. This script modifies the 
#     existing PAM file to enable eDirectory integration. 
#

LOG_FILE=/var/log/novell-pure-ftpd-config.log

PAM_SOURCE_FILE=/etc/pam.d/pure-ftpd
PAM_TMP_FILE=/etc/pam.d/pure-ftpd.ldap

PURE_FTP_CONF_FILE=/etc/pure-ftpd/pure-ftpd.conf
PURE_FTP_CONF_FILE_BKP=/etc/pure-ftpd/pure-ftpd.conf.bkp
PURE_FTP_RC_SCRIPT=/etc/init.d/pure-ftpd
PURE_FTP_TMP_RC_SCRIPT=/tmp/pure-ftpd

log()
{
	echo `date '+%b %e %H:%M:%S'` $1 >> $LOG_FILE
}

case "$1" in
	"-h")
		echo "`basename $0` : configures eDirectory integration with Pure-FTPd"
		echo "Usage : `basename $0`"
		echo ""
		exit 0;

		;;

	*)
		if [ ! -f $LOG_FILE ]
		then
			touch $LOG_FILE
		fi

		log "Beginning Pure-FTPd configuration for eDirectory"

		### Configure /etc/pam.d/pure-ftpd

		# Add the pam_ldap section 
		# Note : this is a Here document (bash)
		cat > $PAM_TMP_FILE  <<-pam_ldap_entries_block
		#####################################################################
		# The following lines have been automatically added                 #
		# by /opt/novell/pure-ftpd/novell-pure-ftpd-config.sh               #
		#                                                                   #
		# This section ensures that Pure-FTPd uses pam_nam for authentication. #
		#####################################################################
		auth       required     pam_listfile.so item=user sense=deny file=/etc/ftpusers onerr=succeed
		auth       required     pam_shells.so
		auth       required     pam_nam.so
		account    required     pam_nam.so
		password   required     pam_nam.so
		session    required     pam_loginuid.so
		session    optional     pam_nam.so
		pam_ldap_entries_block

		echo "" >> $PAM_TMP_FILE

		# Comment out all the existing lines in the file
		# Note : this is a Here document (bash)
		cat >> $PAM_TMP_FILE  <<-pam_unix_comments_block
		###############################################################
		# The following lines have been automatically commented out   #
		# by /opt/novell/pure-ftpd/novell-pure-ftpd-config.sh         #
		###############################################################
		#####        <--- BEGIN commented section --->            #####
		pam_unix_comments_block

		sed -e "s/^/#/g" $PAM_SOURCE_FILE >> $PAM_TMP_FILE
		if [ $? -ne 0 ]
		then
			log "ERROR : Unable to access '$PAM_SOURCE_FILE'"
			exit 1
		fi
		echo "#####        <--- END commented section --->              #####" >> $PAM_TMP_FILE
		echo "" >> $PAM_TMP_FILE

		log "PAM configuration file written to $PAM_TMP_FILE"

		mv $PAM_TMP_FILE /etc/pam.d/pure-ftpd
		log "/etc/pam.d/pure-ftpd modified"

		log "Enabled eDirectory-based authentication for Pure-FTPd"

		echo "" >> $LOG_FILE
esac

sed /'edirectory ldap port'/d $PURE_FTP_CONF_FILE > $PURE_FTP_CONF_FILE_BKP
mv $PURE_FTP_CONF_FILE_BKP $PURE_FTP_CONF_FILE

REMOTE_SERVER=`cat $PURE_FTP_CONF_FILE | grep "^[[:space:]]*remote_server"`
if [ $? -ne 0 ]
then
	echo	"# Enable remote server navigation for ftp server" >> $PURE_FTP_CONF_FILE 
	echo	"remote_server no" >> $PURE_FTP_CONF_FILE
	echo	" " >> $PURE_FTP_CONF_FILE
fi

LIST_REMOTE_SERVER=`cat $PURE_FTP_CONF_FILE | grep "^[[:space:]]*disallow_list_oes_server"`
if [ $? -ne 0 ]
then
	echo	"# Disable site slist command for listing oes servers" >> $PURE_FTP_CONF_FILE 
	echo	"disallow_list_oes_server no" >> $PURE_FTP_CONF_FILE
	echo	" " >> $PURE_FTP_CONF_FILE
fi

USER_SETTING_COMMENTED=0
EDIR_LDAP_PORT=`cat $PURE_FTP_CONF_FILE | grep "^[[:space:]]*edir_ldap_port"` 
if [ $? -ne 0 ]		#it means entry for ldap port may be commented
then
	EDIR_LDAP_PORT=`cat $PURE_FTP_CONF_FILE | grep "edir_ldap_port"`
	if [ $? -ne 0 ]			#we donot have entry for edir_ldap_port
	then
		echo   " " >> $PURE_FTP_CONF_FILE
		echo   "# Uses the specified eDirectory LDAP server port for fetching the details about remote " >> $PURE_FTP_CONF_FILE
       		echo   "# servers as well as user's home directory. Works with both plain-text and secure ports " >> $PURE_FTP_CONF_FILE
        	echo   "# eDirectory LDAP port:0(plain-text)/1(secure)" >> $PURE_FTP_CONF_FILE
        	echo   "# edir_ldap_port 389:0" >> $PURE_FTP_CONF_FILE
		EDIR_LDAP_PORT=`cat $PURE_FTP_CONF_FILE | grep "edir_ldap_port" | awk '{print $3}' | cut -d: -f1`
	else
		USER_SETTING_COMMENTED=1
		EDIR_LDAP_PORT=`cat $PURE_FTP_CONF_FILE | grep "edir_ldap_port" | awk '{print $3}' | cut -d: -f1`
	fi
else
	EDIR_LDAP_PORT=`cat $PURE_FTP_CONF_FILE | grep "^[[:space:]]*edir_ldap_port" | awk '{print $2}' | cut -d: -f1`
fi

#incase of upgrade there is a change in format of eDirectory port.
if [ $EDIR_LDAP_PORT -eq 389 ]
then
	sed 's/.*edir_ldap_port.*/edir_ldap_port 389:0/' $PURE_FTP_CONF_FILE > $PURE_FTP_CONF_FILE_BKP && mv $PURE_FTP_CONF_FILE_BKP $PURE_FTP_CONF_FILE
elif [ $EDIR_LDAP_PORT -eq 636 ]
then
	sed 's/.*edir_ldap_port.*/edir_ldap_port 636:1/' $PURE_FTP_CONF_FILE > $PURE_FTP_CONF_FILE_BKP && mv $PURE_FTP_CONF_FILE_BKP $PURE_FTP_CONF_FILE
elif [ $USER_SETTING_COMMENTED -eq 1 ]
then 
	sed 's/.*edir_ldap_port.*/edir_ldap_port 389:0/' $PURE_FTP_CONF_FILE > $PURE_FTP_CONF_FILE_BKP && mv $PURE_FTP_CONF_FILE_BKP $PURE_FTP_CONF_FILE
fi

DEFAULT_HOME_DIR=`cat $PURE_FTP_CONF_FILE | grep "DefaultHomeDirectory"`
if [ $? -ne 0 ]
then
	echo	" " >> $PURE_FTP_CONF_FILE
	echo	"# Path for default shared home directory" >> $PURE_FTP_CONF_FILE 
	echo	"# DefaultHomeDirectory	/directory" >> $PURE_FTP_CONF_FILE 
	echo	" " >> $PURE_FTP_CONF_FILE
fi 									    

DEFAULT_HOME_DIR_SERVER=`cat $PURE_FTP_CONF_FILE | grep "DefaultHomeDirectoryServer"`
if [ $? -ne 0 ]
then
	echo	" " >> $PURE_FTP_CONF_FILE
	echo	"# DNS Name or IP Address of the server hosting default shared home directory" >> $PURE_FTP_CONF_FILE 
	echo	"# DefaultHomeDirectoryServer	server-name/server-ip-address" >> $PURE_FTP_CONF_FILE 
	echo	" " >> $PURE_FTP_CONF_FILE
fi 									    

ENABLE_REMOTE_HOME_DIR=`cat $PURE_FTP_CONF_FILE | grep "EnableRemoteHomeDirectory"`
if [ $? -ne 0 ]
then
	echo	" " >> $PURE_FTP_CONF_FILE
	echo	"# Enables support for using user's home directory as the default mount point" >> $PURE_FTP_CONF_FILE 
	echo	"# EnableRemoteHomeDirectory	no" >> $PURE_FTP_CONF_FILE 
	echo	" " >> $PURE_FTP_CONF_FILE
fi 									    

DISABLE_ASCII=`cat $PURE_FTP_CONF_FILE | grep "^[[:space:]]*disable_ascii"`
if [ $? -ne 0 ]
then
	echo	"# Disables ASCII mangling. pure-ftpd still accepts the command \"TYPE A\" (ASCII type)," >> $PURE_FTP_CONF_FILE
	echo	"# and will respond positively, but will not do any ASCII processing on the transferred" >> $PURE_FTP_CONF_FILE
	echo	"# file. All files will be sent or saved exactly as they are read or received." >> $PURE_FTP_CONF_FILE
	echo	"disable_ascii	  no" >> $PURE_FTP_CONF_FILE
fi

ALLOW_BACKSLASH_IN_PATH=`cat $PURE_FTP_CONF_FILE | grep "allow_backslash_in_path"`
if [ $? -ne 0 ]
then
	echo	" " >> $PURE_FTP_CONF_FILE
	echo	"# Allows backslash (\) as a valid character in the file object paths specified by clients (Windows)" >> $PURE_FTP_CONF_FILE 
	echo	"# allow_backslash_in_path	no" >> $PURE_FTP_CONF_FILE 
	echo	" " >> $PURE_FTP_CONF_FILE
fi 									    

TLS_Cipher=`grep "TLSCipherSuite" $PURE_FTP_CONF_FILE`
if [ $? -ne 0 ]
then
        echo "" >> $PURE_FTP_CONF_FILE
        echo "" >> $PURE_FTP_CONF_FILE
        echo    "# List of ciphers that will be accepted for SSL/TLS connections" >> $PURE_FTP_CONF_FILE
        echo    "# TLSCipherSuite           -S:HIGH:MEDIUM:+TLSv1:!SSLv2:+SSLv3">> $PURE_FTP_CONF_FILE
fi

USE_SMB_FOR_EDIR_USERS=`cat $PURE_FTP_CONF_FILE | grep "^[[:space:]]*use_smb_for_edir_users"`
if [ $? -ne 0 ]
then
	echo    "# Use SMB for remote access by eDirectory users" >> $PURE_FTP_CONF_FILE
	echo    "use_smb_for_edir_users   no" >> $PURE_FTP_CONF_FILE
	echo    " " >> $PURE_FTP_CONF_FILE
fi

exit 0
