#!/usr/bin/env python3

# (c) Copyright [2020 - 2021] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (Micro Focus) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.


import os
import json
import fcntl
import subprocess
from time import strptime, mktime
from collections import OrderedDict

#Write the health of Pure-FTPd service to /var/opt/novell/pure-ftpd/pure-ftpd.json
def writeJSON(dictionary):
	try:
		with open("/var/opt/novell/pure-ftpd/pure-ftpd.json", "w") as pureftpdstatusfile:
			fcntl.flock(pureftpdstatusfile, fcntl.LOCK_EX | fcntl.LOCK_NB)
			json.dump(dictionary, pureftpdstatusfile, indent=4, separators=(", ", ": "))
			fcntl.flock(pureftpdstatusfile, fcntl.LOCK_UN)
	except IOError:
		raise Exception("Failed to open/write the Json file /var/opt/novell/pure-ftpd/pure-ftpd.json")

#Get Pure-FTPd Health status data
def genHealthStatus():
	pureftpdsystemctl_cmd = "systemctl is-active pure-ftpd"
	pureftpsstatus = subprocess.getoutput(pureftpdsystemctl_cmd)
	jsonpureftpd_stream = OrderedDict()
	jsonpureftpd_stream["serviceName"] = "FTP Server"
	jsonpureftpd_stream["status"] = ""
	jsonpureftpd_stream["runningSince"] = ""
	jsonpureftpd_stream["AdditionalInfo"] = ""
	jsonpureftpd_stream["children"] = None

	if(pureftpsstatus == "inactive"):
		jsonpureftpd_stream["status"] = "UnHealthy"
		jsonpureftpd_stream["runningSince"] = 0
		jsonpureftpd_stream["AdditionalInfo"] = ["FTP Service","Common_Inactive","Common_ResolveService"]
	else:
		pureftpdtimestamp_cmd  = "systemctl show -p ExecMainStartTimestamp pure-ftpd"
		pureftpdtimestatus = subprocess.getoutput(pureftpdtimestamp_cmd)
		timestamp_output = pureftpdtimestatus.strip().split("=")
		target_timestamp = strptime(timestamp_output[1], '%a %Y-%m-%d %H:%M:%S %Z')
		epoch_time = mktime(target_timestamp)
		jsonpureftpd_stream["status"] = "Healthy"
		jsonpureftpd_stream["runningSince"] = int(epoch_time)
	return jsonpureftpd_stream

healthData = genHealthStatus()

try:
	writeJSON(healthData)
except Exception:
	exit(1)

